Garfield.trainer.GarfieldTrainer
================================

.. currentmodule:: Garfield.trainer

.. autoclass:: GarfieldTrainer

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GarfieldTrainer.__init__
      ~GarfieldTrainer.is_early_stopping
      ~GarfieldTrainer.plot_loss_curves
      ~GarfieldTrainer.save
      ~GarfieldTrainer.test_metrics_epoch
      ~GarfieldTrainer.train
      ~GarfieldTrainer.validate_end
   
   

   
   
   